@@ -13,7 +13,7 @@
 
 ##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
 
-Version = '1.3-1'
+Version = '1.5'
 
 import os
 import sys
@@ -184,7 +184,7 @@ class CSSUfeaturesAbout(QtGui.QMainWindow):
         aboutIcon.resize(128,128)
         aboutLayout.addWidget(aboutIcon)
 
-        aboutLabel = QLabel('''<center><b>CSSU features</b> %s
+        aboutLabel = QLabel('''<center><b>CSSU Features Configuration</b> %s
                                    <br>
                                    <br>
                                    <b>The CSSU Features application is 
@@ -253,7 +253,7 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
              QtCore.QObject.connect(self.ui.actionQuit, QtCore.SIGNAL('triggered()'), QtGui.qApp, QtCore.SLOT('quit()'))
              QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL('triggered()'), self.doAbout)
              QtCore.QObject.connect(self.ui.actionRestoreDefaults, QtCore.SIGNAL('triggered()'), self.doRestoreDefaults)
-             QtCore.QObject.connect(self.ui.actionRestartHildon, QtCore.SIGNAL('triggered()'), self.doRestartHildon)
+             QtCore.QObject.connect(self.ui.actionRebootDevice, QtCore.SIGNAL('triggered()'), self.doRebootDevice)
              
              ## Check which config file to use.
              checkConfigFile()
@@ -280,16 +280,15 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
              else: 
                  message = 'The default transitions.ini file have been restored to the system.\n\nINFO: Some of its settings will appear on the next reboot.'
              
-        def doRestartHildon(self):
-             '''Restart hildon for the settings to take effect.'''
+        def doRebootDevice(self):
+             '''Reboot Device for the settings to take effect.'''
              
-             message = 'INFO: Hildon is going to be restarted.\nThe application will now exit..'
+             message = 'INFO: Device is going to be restarted.\nThe application is exiting..'
              showQuickMessage(message)
              
-             os.system('sudo %s/updateTransitions restartHildon &' % PathApp)
+             os.system('sudo %s/updateTransitions rebootDevice &' % PathApp)
              sys.exit(1)
-
-            
+     
         def doSetCurrent(self):
              ''' Set CURRENT values in the GUI''' 
 
@@ -310,7 +309,7 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
                  self.ui.comboBoxRotationAxis.setCurrentIndex(int(dataVars['zaxisrotation']))
                  self.ui.comboBoxForcedRotation.setCurrentIndex(int(dataVars['forcerotation']))
                  self.ui.comboBoxTactile.setCurrentIndex(int(dataVars['tactilepopups']))
-                 self.ui.lineEditParallax.setText(dataVars['parallax'])
+                 self.ui.doubleSpinBoxParallax.setValue(float(dataVars['parallax']))
                  
                  message = 'The CURRENT configuration options are shown.'
                  showQuickMessage(message)
@@ -328,7 +327,7 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
              self.ui.comboBoxForcedRotation.setCurrentIndex(0)
              self.ui.comboBoxTactile.setCurrentIndex(0)
              self.ui.comboBoxZoomPress.setCurrentIndex(0)
-             self.ui.lineEditParallax.setText('1.3')
+             self.ui.doubleSpinBoxParallax.setValue(float('1.3'))
              
              message = 'The DEFAULT configuration options are shown.'
              showQuickMessage(message)
@@ -346,7 +345,7 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
              ForcedRotation  = self.ui.comboBoxForcedRotation.currentIndex()
              Tactile         = self.ui.comboBoxTactile.currentIndex()
              ZoomPress       = self.ui.comboBoxZoomPress.currentIndex()
-             Parallax        = self.ui.lineEditParallax.text()
+             Parallax        = self.ui.doubleSpinBoxParallax.value()
 
              #Update of the System config file.
              os.rename( PathTemp + ConfigTempSystem, PathTemp + ConfigTempSystem + "~" )
